pub fn run() -> Result<()>Expand description
Executes the static site generation process.
Parses CLI arguments, runs the plugin pipeline around compilation, and starts a local dev server. This function blocks indefinitely while the server is running.